@@ -45,7 +45,7 @@ class DrivenControl:
         of segments.
     rabi_rates : np.ndarray, optional
         The Rabi rates :math:`\{\Omega_n\}` for each segment, in units of radians per second. Every
-        element must be non-negative. Represented as a 1D array of length :math:`N`, where :math:`N`
+        element must be nonnegative. Represented as a 1D array of length :math:`N`, where :math:`N`
         is number of segments. You can omit this field if the Rabi rate is zero on all segments.
     azimuthal_angles : np.ndarray, optional
         The azimuthal angles :math:`\{\phi_n\}` for each segment. Represented as a 1D array of
@@ -107,7 +107,7 @@ class DrivenControl:
         # check if all the durations are greater than zero
         check_arguments(
             all(durations > 0),
-            "Duration of driven control segments must all be greater than zero.",
+            "Duration of driven control segments must all be positive.",
             {"durations": durations},
         )
 
@@ -120,7 +120,7 @@ class DrivenControl:
 
         check_arguments(
             len(input_lengths) == 1,
-            "If set, rabi rates, azimuthal angles, detunings and durations "
+            "If set, Rabi rates, azimuthal angles, detunings and durations "
             "must be of same length",
             {
                 "rabi_rates": rabi_rates,
@@ -144,10 +144,10 @@ class DrivenControl:
         azimuthal_angles = np.asarray(azimuthal_angles, dtype=float)
         detunings = np.asarray(detunings, dtype=float)
 
-        # check if all the rabi_rates are greater than zero
+        # check if all the rabi_rates are nonnegative
         check_arguments(
             all(rabi_rates >= 0.0),
-            "All rabi rates must be greater than zero.",
+            "All Rabi rates must be nonnegative.",
             {"rabi_rates": rabi_rates},
         )
 
@@ -650,13 +650,13 @@ class DrivenControl:
         )
 
         driven_control.append(
-            f"Rabi Rates = [{pretty_rabi_rates}] x {self.maximum_rabi_rate}"
+            f"Rabi Rates = [{pretty_rabi_rates}] × {self.maximum_rabi_rate}"
         )
-        driven_control.append(f"Azimuthal Angles = [{pretty_azimuthal_angles}] x pi")
+        driven_control.append(f"Azimuthal Angles = [{pretty_azimuthal_angles}] × pi")
         driven_control.append(
-            f"Detunings = [{pretty_detuning}] x {self.maximum_detuning}"
+            f"Detunings = [{pretty_detuning}] × {self.maximum_detuning}"
         )
-        driven_control.append(f"Durations = [{pretty_durations}] x {self.duration}")
+        driven_control.append(f"Durations = [{pretty_durations}] × {self.duration}")
         driven_control_string = "\n".join(driven_control)
 
         return driven_control_string
