@@ -98,7 +98,7 @@ class DynamicDecouplingSequence:
         rabi_rotations = np.asarray(rabi_rotations, dtype=float)
         check_arguments(
             np.all(rabi_rotations >= 0),
-            "Rabi rotations must be non-negative.",
+            "Rabi rotations must be nonnegative.",
             {"rabi_rotations": rabi_rotations},
         )
 
@@ -198,19 +198,19 @@ class DynamicDecouplingSequence:
         sequence_string.append(f"Duration = {self.duration}")
 
         sequence_string.append(
-            f"Offsets = [{_array_to_str(self.offsets / self.duration)}] x {self.duration}"
+            f"Offsets = [{_array_to_str(self.offsets / self.duration)}] × {self.duration}"
         )
 
         sequence_string.append(
-            f"Rabi Rotations = [{_array_to_str(self.rabi_rotations / np.pi)}] x pi"
+            f"Rabi Rotations = [{_array_to_str(self.rabi_rotations / np.pi)}] × pi"
         )
 
         sequence_string.append(
-            f"Azimuthal Angles = [{_array_to_str(self.azimuthal_angles / np.pi)}] x pi"
+            f"Azimuthal Angles = [{_array_to_str(self.azimuthal_angles / np.pi)}] × pi"
         )
 
         sequence_string.append(
-            f"Detuning Rotations = [{_array_to_str(self.detuning_rotations / np.pi)}] x pi"
+            f"Detuning Rotations = [{_array_to_str(self.detuning_rotations / np.pi)}] × pi"
         )
 
         return "\n".join(sequence_string)
@@ -289,7 +289,7 @@ def convert_dds_to_driven_control(
     dynamic_decoupling_sequence : DynamicDecouplingSequence
         The base DDS. Its offsets should be sorted in ascending order in time.
     maximum_rabi_rate : float
-        Maximum rabi rate.
+        Maximum Rabi rate.
     maximum_detuning_rate : float
         Maximum detuning rate.
     minimum_segment_duration : float, optional
@@ -309,7 +309,7 @@ def convert_dds_to_driven_control(
     ------
     ArgumentsValueError
         Raised when an argument is invalid or a valid driven control cannot be
-        created from the sequence parameters, maximum rabi rate and maximum detuning
+        created from the sequence parameters, maximum Rabi rate and maximum detuning
         rate provided.
 
     Notes
@@ -342,7 +342,7 @@ def convert_dds_to_driven_control(
     )
     check_arguments(
         maximum_rabi_rate > 0,
-        "Maximum rabi rate must be positive.",
+        "Maximum Rabi rate must be positive.",
         {"maximum_rabi_rate": maximum_rabi_rate},
     )
 
@@ -370,7 +370,7 @@ def convert_dds_to_driven_control(
         _check_valid_operation(
             rabi_rotations=rabi_rotations, detuning_rotations=detuning_rotations
         ),
-        "Sequence operation includes rabi rotation and "
+        "Sequence operation includes Rabi rotation and "
         "detuning rotation at the same instance.",
         {"dynamic_decoupling_sequence": dynamic_decoupling_sequence},
         extras={
