@@ -173,7 +173,7 @@ def new_ramsey_sequence(duration, pre_post_rotation=False, name=None):
     """
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positive.",
         {"duration": duration},
     )
 
@@ -230,7 +230,7 @@ def new_spin_echo_sequence(duration, pre_post_rotation=False, name=None):
 
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positive.",
         {"duration": duration},
     )
 
@@ -305,12 +305,12 @@ def new_carr_purcell_sequence(
 
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positive.",
         {"duration": duration},
     )
     check_arguments(
         offset_count >= 1,
-        "Number of offsets must be greater than zero.",
+        "Number of offsets must be positive.",
         {"offset_count": offset_count},
     )
 
@@ -388,12 +388,12 @@ def new_cpmg_sequence(duration, offset_count, pre_post_rotation=False, name=None
 
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positive.",
         {"duration": duration},
     )
     check_arguments(
         offset_count >= 1,
-        "Number of offsets must be greater than zero.",
+        "Number of offsets must be positive.",
         {"offset_count": offset_count},
     )
 
@@ -467,12 +467,12 @@ def new_uhrig_sequence(duration, offset_count, pre_post_rotation=False, name=Non
 
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positive.",
         {"duration": duration},
     )
     check_arguments(
         offset_count >= 1,
-        "Number of offsets must be greater than zero.",
+        "Number of offsets must be positive.",
         {"offset_count": offset_count},
     )
 
@@ -546,12 +546,12 @@ def new_periodic_sequence(duration, offset_count, pre_post_rotation=False, name=
 
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positve.",
         {"duration": duration},
     )
     check_arguments(
         offset_count >= 1,
-        "Number of offsets must be greater than zero.",
+        "Number of offsets must be positive.",
         {"offset_count": offset_count},
     )
 
@@ -649,7 +649,7 @@ def new_walsh_sequence(duration, paley_order, pre_post_rotation=False, name=None
 
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positive.",
         {"duration": duration},
     )
     check_arguments(
@@ -771,17 +771,17 @@ def new_quadratic_sequence(
 
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positive.",
         {"duration": duration},
     )
     check_arguments(
         inner_offset_count >= 1,
-        "Number of offsets of inner pulses must be greater than zero.",
+        "Number of offsets of inner pulses must be positive.",
         {"inner_offset_count": inner_offset_count},
     )
     check_arguments(
         outer_offset_count >= 1,
-        "Number of offsets of outer pulses must be greater than zero.",
+        "Number of offsets of outer pulses must be positive.",
         {"outer_offset_count": outer_offset_count},
     )
 
@@ -893,12 +893,12 @@ def new_x_concatenated_sequence(
 
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positive.",
         {"duration": duration},
     )
     check_arguments(
         concatenation_order >= 1,
-        "Concatenation oder must be greater than zero.",
+        "Concatenation order must be positive.",
         {"concatenation_order": concatenation_order},
     )
 
@@ -998,12 +998,12 @@ def new_xy_concatenated_sequence(
 
     check_arguments(
         duration > 0,
-        "Sequence duration must be greater than zero.",
+        "Sequence duration must be positive.",
         {"duration": duration},
     )
     check_arguments(
         concatenation_order >= 1,
-        "Concatenation oder must be greater than zero.",
+        "Concatenation order must be positive.",
         {"concatenation_order": concatenation_order},
     )
 
